const express = require('express');
const productController = require('../controllers/productController');
const passport = require('passport');
const authorize = require('../middlewares/authorize');
const multer = require('multer');
const Product = require('../models/productschema'); 
const path = require('path');
const fs = require('fs');

const router = express.Router();

const storage = multer.diskStorage({
    destination: function (req, file, cb) {
      const dir = './public'; // Directory to save uploaded files
      if (!fs.existsSync(dir)) {
        fs.mkdirSync(dir); // Create directory if it doesn't exist
      }
      cb(null, dir);
    },
    filename: function (req, file, cb) {
      cb(null, Date.now() + path.extname(file.originalname)); // Save file with timestamp
    },
  });
  
  const upload = multer({ storage: storage });

  router.post('/', passport.authenticate('jwt', { session: false }), upload.array('photos', 5), async (req, res) => {
    try {
      const { title, content, price, size, color, quality, status, method } = req.body;
      const photos = req.files.map(file => file.path); // Get the file paths of uploaded photos
  
      // Validate incoming data
      if (!title || !content || price <= 0 || size <= 0) {
        return res.status(400).json({ message: 'Invalid input data' });
      }
  
      const product = new Product({
        title,
        content,
        price,
        size,
        color,
        quality,
        status,
        method,
        photos, // Store the array of photo paths in the product
        userId: req.user._id, // Make sure this line is included to set the user ID
      });

       if (req.user) {
    // Set the user_id property of the product to the authenticated user's id
    product.user_id = req.user._id; // or req.user.id, depending on your user model
  } else {
    throw new ApiError(httpStatus.UNAUTHORIZED, 'Unauthorized');
  }
  
      await product.save();
      res.status(201).json({ message: 'Product created successfully', product });
    } catch (error) {
      console.error('Error creating product:', error); // Log the error for debugging
      res.status(500).json({ message: 'Internal server error', error: error.message });
    }
  }); 


//router.post('/', passport.authenticate('jwt', { session: false }), productController.createProduct);
router.get('/', productController.getProducts);
router.get('/myproducts', passport.authenticate('jwt', { session: false }), productController.myProducts);
router.get('/slug/:slug', productController.getProductwithslug);
router.get('/:id', productController.getProduct);
router.put('/:id',passport.authenticate('jwt', { session: false }), productController.updateProduct);
router.delete('/:id',passport.authenticate('jwt', { session: false }), productController.deleteProduct);

module.exports = router;